@@ -85,7 +85,7 @@ or just put wide-margin comparisons in place is up to you.
 =head1 SUBROUTINES
 
 
-=head2 expected_queries($schema, $sub_ref, $expected_table_operations) : $result | @result
+=head2 expected_queries( $schema, $sub_ref, $expected_table_operations = {} ) : $result | @result
 
 Run $sub_ref and collect stats for queries executed on $schema, then
 test that they match the $expected_table_operations.
@@ -143,7 +143,7 @@ stats before finally calling $queries->test().
 Return the return value of $sub_ref->().
 
 
-=head2 test($expected_table_operations) : Bool
+=head2 test( $expected_table_operations = {} ) : Bool
 
 Test the collected queries against $expected_table_operations (see
 abov) and either pass or fail a Test::More test.
@@ -233,7 +233,7 @@ queries until after they have been run.
 =cut
 
 package Test::DBIC::ExpectedQueries;
-$Test::DBIC::ExpectedQueries::VERSION = '1.003';
+$Test::DBIC::ExpectedQueries::VERSION = '1.004';
 use Moo;
 BEGIN {extends "Attribute::Exporter"};
 
@@ -251,6 +251,7 @@ use Test::DBIC::ExpectedQueries::Query;
 
 sub expected_queries : export_def {
     my ($schema, $subref, $expected) = @_;
+    $expected ||= {};
     local $Test::Builder::Level = $Test::Builder::Level + 1;
 
     my $queries = Test::DBIC::ExpectedQueries->new({ schema => $schema });
@@ -361,12 +362,15 @@ sub run {
 sub test {
     my $self = shift;
     my ($expected) = @_;
+    $expected ||= {};
     local $Test::Builder::Level = $Test::Builder::Level + 1;
 
     my $failure_message = $self->check_table_operation_counts($expected);
     my $unknown_warning = $self->unknown_warning;
 
     $self->clear_queries_sql();
+    $self->clear_queries();
+    $self->clear_table_operation_count();
 
 
     my $test_description = "Expected queries for tables";
